﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Threading;

using SII.SPS.Windows.NetCompactFramework.PrintClassLibrary.MobilePrinter;

namespace SiiMpPrinterSample
{
    /// <summary>
    /// Sample class
    /// </summary>
    public partial class MPSample : Form
    {
        public String m_Address, m_BTAddress, m_IpAddress, m_UsbAddress;    // Various address
        public DiscoveryForm m_PrinterListForm;                             // DiscoveryForm class
        public StatusCallbackForm m_StatusCallbackForm;                     // Status callback class
        public PrinterManager mPrinterManager;                              // PrinterManager class
        public PrinterModel m_PrinterModel;                                 // Printer model
        String m_CurrentPath;                                               // Current path name
        String PRINTER_MODEL_MP_A40 = "MP-A40";                             // Printer model name of MP-A40.
        String PRINTER_MODEL_MP_B30 = "MP-B30";                             // Printer model name of MP-B30.
        String PRINTER_MODEL_MP_B20 = "MP-B20";                             // Printer model name of MP-B20.


        #region /// Sample string of receipt and bar code //////////////////////////////////
        String receiptTitle = "Receipt Sample\n\n";
        String receiptTime = "No.123456789  03/04/11 12:49 PM\n";
        String receiptContent =
                "-------------------------------\n" +
                        "GRILLED CHICKEN BREAST  $ 18.50\n" +
                        "SIRLOIN STEAK           $ 32.00\n" +
                        "ROAST LAMB              $ 20.00\n" +
                        "SALAD                   $ 10.00\n" +
                        "COKE                    $  3.50\n" +
                        "COKE                    $  3.50\n" +
                        "ICE CREAM               $  5.00\n" +
                        "CHINESE NOODLE          $ 15.00\n" +
                        "SUKIYAKI                $ 30.00\n" +
                        "SANDWICH                $ 10.00\n" +
                        "PIZZA                   $ 20.00\n" +
                        "TEA                     $  3.50\n" +
                        "COFFEE                  $  3.50\n\n" +
                        "-------------------------------\n" +
                        "        SUBTOTAL       $ 174.50\n" +
                        "        SALES TAX      $   8.73\n" +
                        "        TOTAL          $ 183.23\n\n" +
                        "Thank you and see you again!\n";
        String receiptBarcode = "12345678905";
        String receipt2Dcode = "ABC0123";
        #endregion

        #region /// Constants //////////////////////////////////
        const Int32 WRITE_TIMEOUT = 25000;              // Send timeout time
        const Int32 READ_TIMEOUT = 25000;               // Receive timeout time
        const Int32 STANDARD_MODE = 0;                  // Print mode: Standard mode
        const Int32 PAGE_MODE = 1;                      // Print mode: Page mode
        const Int32 STD_MODE_LEFT_MARGIN = 0;           // Left margin
        const Int32 STD_MODE_PRINT_AREA_WIDTH_MPA40 = 832; // Print area width
        const Int32 STD_MODE_PRINT_AREA_WIDTH_MPB30 = 576; // Print area width
        const Int32 STD_MODE_PRINT_AREA_WIDTH_MPB20 = 384; // Print area width
        const Int32 WIDTH_RECEIPT_MPA40 = 576;          // Print receipt area width
        const Int32 WIDTH_RECEIPT_MPB30 = 576;          // Print receipt area width
        const Int32 WIDTH_RECEIPT_MPB20 = 384;          // Print receipt area width
        const Int32 HEIGHT_RECEIPT = 1400;              // Printing area height
        const Int32 WIDTH_FONT_A = 12;                  // Horizontal direction print width
        const Int32 HEIGHT_FONT_A = 24;                 // Vertical direction printing position

        const Int32 LINE_SPACE = 34;                    // Line feed
        const Int32 RIGHT_SPACE = 0;                    // Right amount of space
        const Int32 THICKNESS = 2;                      // Specifying the borders thickness
        const Int32 HORIZONTAL_POS = 0;                 // Printing position
        const Int32 HEIGHT_BARCODE = 162;               // The height of the bar code
        const Int32 HEIGHT_2DCODE = 10;                 // Module height
        const Int32 COLUM_2DCODE = 0;                   // Number of columns
        const Int32 ROW_2DCODE = 0;                     // Number of rows
        #endregion

        /// <summary>
        /// Constructor
        /// </summary>
        public MPSample()
        {
            InitializeComponent();

            // To create a PrinterManager class.
            mPrinterManager = new PrinterManager();

            // If you want to run the sample application, you need to copy a file that was distributed to the following folder.
            // PC\USER\\\Program Files\siimpprintersample\data
            m_CurrentPath = System.IO.Path.GetDirectoryName(System.Reflection.Assembly.GetExecutingAssembly().GetModules()[0].FullyQualifiedName);
            m_CurrentPath += "\\data\\";

            // Here, we will set the initial value.
            m_Address = "";
            m_BTAddress = "";
            m_IpAddress = "";
            m_UsbAddress = "LPT1:";

            // Add items to the list box.
            listBox_PrinterModel.Items.Add(PRINTER_MODEL_MP_A40);
            listBox_PrinterModel.Items.Add(PRINTER_MODEL_MP_B30);
            listBox_PrinterModel.Items.Add(PRINTER_MODEL_MP_B20);
            listBox_PrinterModel.SelectedIndex = 0;
            m_PrinterModel = PrinterModel.PRN_MODEL_MP_A40;

        }

        /// <summary>
        /// Destructor
        /// </summary>
        ~MPSample()
        {
            Dispose();
        }

        #region /// Control event //////////////////////////////////

        /// <summary>
        /// Display the DiscoveryForm, and set a variety of address that has been selected to the member variable.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void button_DiscoveryList_Click(object sender, EventArgs e)
        {
            try
            {
                // To create a DiscoveryForm class.
                m_PrinterListForm = new DiscoveryForm(this);
            }
            catch (PrinterException)
            {
                return;
            }

            // Display the DiscoveryForm
            DialogResult r = m_PrinterListForm.ShowDialog();
            if (r == DialogResult.OK)
            {
                // If DialogResult.OK is returned, Setting the selected address to the member variable.
                if (radioButton1.Checked)
                {
                    // If the Bluetooth has been selected
                    m_BTAddress = m_PrinterListForm.Address;
                    m_Address = m_BTAddress;

                }
                else
                {
                    // If TCP / IP has been selected
                    m_IpAddress = m_PrinterListForm.Address;
                    m_Address = m_IpAddress;
                }

                textBox_Address.Text = m_Address;

            }

            // To dispose the resource.
            m_PrinterListForm.Dispose();
        }

        /// <summary>
        /// Process when the Bluetooth radio button is pressed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void radioButton1_CheckedChanged(object sender, EventArgs e)
        {
            // The address and the input text box "List" button to display state.
            textBox_Address.Enabled = true;
            button_DiscoveryList.Enabled = true;

            // To set a member variable of the Bluetooth address to the address input for the text box.
            textBox_Address.Text = m_BTAddress;
        }

        /// <summary>
        /// Process when the USB radio button is pressed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void radioButton2_CheckedChanged(object sender, EventArgs e)
        {
            // Address and the input text box to "List" button to hide state.
            textBox_Address.Enabled = false;
            button_DiscoveryList.Enabled = false;

            // To set a member variable of the USB address to the address input for the text box.
            textBox_Address.Text = m_UsbAddress;
        }

        /// <summary>
        /// Process when the TCP / IP radio button is pressed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void radioButton3_CheckedChanged(object sender, EventArgs e)
        {
            // The address and the input text box "List" button to display state.
            textBox_Address.Enabled = true;
            button_DiscoveryList.Enabled = true;

            // To set a member variable of the TCP / IP address to the address input for the text box.
            textBox_Address.Text = m_IpAddress;
        }

        /// <summary>
        /// Processing in the case of "StandardModeSample" button has been pressed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void button_StandardMode_Click(object sender, EventArgs e)
        {
            SendSampleReceiptCmd(STANDARD_MODE);
        }

        /// <summary>
        /// Processing in the case of "PageModeSample" button has been pressed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void button_PageMode_Click(object sender, EventArgs e)
        {
            SendSampleReceiptCmd(PAGE_MODE);
        }

        /// <summary>
        /// Processing in the case of "SendFile" button has been pressed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void button_SendDataFile_Click(object sender, EventArgs e)
        {
            SendDataFileSample();
        }

        /// <summary>
        /// Processing when the "Barcode" button has been pressed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void button_Barcode_Click(object sender, EventArgs e)
        {
            BarcodeSample();
        }

        /// <summary>
        /// Processing in the case of "2Dcode" button has been pressed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void button_2Dcode_Click(object sender, EventArgs e)
        {
            TwoDCodeSample();
        }

        /// <summary>
        /// Processing in the case of "CallbackFunction" button has been pressed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void button_Callback_Click(object sender, EventArgs e)
        {
            // To create a StatusCallbackForm class.
            try
            {
                m_StatusCallbackForm = new StatusCallbackForm(this);
            }
            catch (PrinterException)
            {
                return;
            }

            // Display the StatusCallbackForm
            DialogResult r = m_StatusCallbackForm.ShowDialog();
            if (r == DialogResult.OK)
            {
                // If DialogResult.OK is returned (it does not do anything in the sample.)
            }

            // To dispose the resource.
            m_StatusCallbackForm.Dispose();

        }
        #endregion

        #region /// Sample test //////////////////////////////////

        /// <summary>
        /// Get the selected printer interface.
        /// </summary>
        /// <returns>PrinterInterface</returns>
        public PrinterInterface GetCurrentInterface()
        {
            // Switch the return value by the state of the radio buttons.
            if (radioButton1.Checked)
            {
                return PrinterInterface.PRN_IF_BT;
            }
            else if (radioButton2.Checked)
            {
                return PrinterInterface.PRN_IF_USB;
            }
            else
            {
                return PrinterInterface.PRN_IF_TCP;
            }
        }

        /// <summary>
        /// Get the address of the selected printer interface.
        /// </summary>
        /// <returns>address</returns>
        public String GetCurrentAddress()
        {
            m_Address = textBox_Address.Text;
            if (radioButton1.Checked)
            {
                m_BTAddress = m_Address;
            }
            else if (radioButton2.Checked)
            {
                m_UsbAddress = m_Address;
            }
            else
            {
                m_IpAddress = m_Address;
            }
            return m_Address;
        }

        /// <summary>
        /// Processing in the case of "StandardModeSample" button or "PageModeSample" button has been pressed
        /// </summary>
        /// <param name="printMode">Print mode. In the case of StandardModeSample:STANDARD_MODE, In the case of PageModeSample:PAGE_MODE</param>
        private void SendSampleReceiptCmd(Int32 printMode)
        {
            // Start position and the print area width and height
            Int32 startX = 0, startY = 0;
            Int32 width = 0;
            Int32 receiptWidth = 0;
            Int32 areaWidth = 0;
            Int32 height = HEIGHT_RECEIPT;

            if (m_PrinterModel == PrinterModel.PRN_MODEL_MP_A40)
            {
                width = WIDTH_RECEIPT_MPA40;
                areaWidth = STD_MODE_PRINT_AREA_WIDTH_MPA40;
                receiptWidth = WIDTH_RECEIPT_MPA40;
            }
            else if (m_PrinterModel == PrinterModel.PRN_MODEL_MP_B30)
            {
                width = WIDTH_RECEIPT_MPB30;
                areaWidth = STD_MODE_PRINT_AREA_WIDTH_MPB30;
                receiptWidth = WIDTH_RECEIPT_MPB30;
            }
            else if (m_PrinterModel == PrinterModel.PRN_MODEL_MP_B20)
            {
                width = WIDTH_RECEIPT_MPB20;
                areaWidth = STD_MODE_PRINT_AREA_WIDTH_MPB20;
                receiptWidth = WIDTH_RECEIPT_MPB20;
            }
            else{
                width = WIDTH_RECEIPT_MPB30;
                areaWidth = STD_MODE_PRINT_AREA_WIDTH_MPB30;
                receiptWidth = WIDTH_RECEIPT_MPB30;
            }

            try
            {
                // Open the PrinterManager.
                Open();

                if (mPrinterManager.IsOpened)
                {
                    // To set the value, such as the timeout time and the character code set.
                    mPrinterManager.SetWriteTimeout(WRITE_TIMEOUT);
                    mPrinterManager.SetResponseTimeout(READ_TIMEOUT);
                    mPrinterManager.SelectCharacterSet(CharacterSet.CODEPAGE_437);
                    mPrinterManager.SelectInternationalCharacterSet(InternationalCharacterSet.INT_CHAR_SET_USA);
                    mPrinterManager.ControlTransaction(TransactionFunction.TRANSACTION_START);

                    // Print mode and set a unique value.
                    switch (printMode)
                    {
                        case STANDARD_MODE:
                            // Select the Standard mode, and set the alignment and the printing area.
                            mPrinterManager.SelectStandardMode();
                            mPrinterManager.SetStandardModeArea(STD_MODE_LEFT_MARGIN,
                                    areaWidth);
                            mPrinterManager.SetStandardModeAlignment(Alignment.ALIGN_CENTER);
                            break;
                        case PAGE_MODE:
                            // Select a page mode.
                            mPrinterManager.SelectPageMode(startX,
                                    startY,
                                    receiptWidth,
                                    HEIGHT_RECEIPT,
                                    Direction.DIRECTION_LEFT_TO_RIGHT);
                            break;
                        default:
                            break;
                    }

                    // Set the right amount of space line feed amount and character.
                    mPrinterManager.SetLineSpacing(LINE_SPACE);
                    mPrinterManager.SetCharacterRightSpace(RIGHT_SPACE);

                    //===== Title =====
                    // To the appropriate settings by the print mode, and then printing the title.
                    switch (printMode)
                    {
                        case STANDARD_MODE:
                            // Set the string of title.
                            receiptTitle = "Receipt Sample\n\n";

                            // In the case of Standard mode, and specify the absolute position.
                            mPrinterManager.SetHorizontalPosition(HORIZONTAL_POS);
                            break;
                        case PAGE_MODE:
                            // In the case of the page mode, and draw a rectangle.
                            mPrinterManager.PrintPageModeRectangle(startX,
                                    startY,
                                    receiptWidth,
                                    HEIGHT_RECEIPT,
                                    THICKNESS);

                            // Set the string of title.
                            receiptTitle = "Receipt Sample";

                            // To calculate the width and height of the origin and the print area of the vertical and horizontal directions.
                            int widthReceiptTitle = ((WIDTH_FONT_A + RIGHT_SPACE) * 2) * receiptTitle.Length;
                            startX = (receiptWidth - widthReceiptTitle) / 2;
                            startY += 80;
                            width = receiptWidth - startX;
                            height = HEIGHT_FONT_A * 1;

                            // Select a page mode.
                            mPrinterManager.SelectPageMode(startX,
                                    startY,
                                    width,
                                    height,
                                    Direction.DIRECTION_LEFT_TO_RIGHT);
                            mPrinterManager.SetPageModeVerticalPosition(HEIGHT_FONT_A);
                            break;
                        default:
                            break;
                    }

                    // Specify the character decoration.
                    mPrinterManager.SetCharacterFormatting(CharacterType.CHAR_TYPE_FONT_A,
                                                            CharacterScale.CHAR_SCALE_X1,
                                                            CharacterScale.CHAR_SCALE_X2,
                                                            Underline.CHAR_UNDERLINE_NONE,
                                                            Bold.CHAR_BOLD_ON,
                                                            Reverse.CHAR_REVERSE_OFF,
                                                            Rotate.ROTATE_NONE);

                    // To print the title.
                    mPrinterManager.PrintText(receiptTitle);

                    //===== No, and Time =====
                    switch (printMode)
                    {
                        case STANDARD_MODE:
                            // Set the date and time.
                            receiptTime = "No.123456789  03/04/11 12:49 PM\n";

                            // To specify the absolute position and character decoration.
                            mPrinterManager.SetHorizontalPosition(HORIZONTAL_POS);
                            mPrinterManager.SetCharacterFormatting(CharacterType.CHAR_TYPE_FONT_A,
                                    CharacterScale.CHAR_SCALE_X1,
                                    CharacterScale.CHAR_SCALE_X1,
                                    Underline.CHAR_UNDERLINE_NONE,
                                    Bold.CHAR_BOLD_OFF,
                                    Reverse.CHAR_REVERSE_OFF,
                                    Rotate.ROTATE_NONE);
                            //do not print time here
                            break;
                        case PAGE_MODE:
                            // Set the date and time.
                            receiptTime = "No.123456789  03/04/11 12:49 PM";
                            startX = (receiptWidth - ((WIDTH_FONT_A + RIGHT_SPACE) * receiptTime.Length)) / 2;
                            startY += height + 80;
                            width = receiptWidth - startX;
                            height = HEIGHT_FONT_A * 1;

                            // Select a page mode.
                            mPrinterManager.SelectPageMode(startX,
                                    startY,
                                    width,
                                    height,
                                    Direction.DIRECTION_LEFT_TO_RIGHT);

                            // To specifies the vertical direction of the absolute position of the page mode.
                            mPrinterManager.SetPageModeVerticalPosition(HEIGHT_FONT_A);

                            // Specify the character decoration.
                            mPrinterManager.SetCharacterFormatting(CharacterType.CHAR_TYPE_FONT_A,
                                    CharacterScale.CHAR_SCALE_X1,
                                    CharacterScale.CHAR_SCALE_X1,
                                    Underline.CHAR_UNDERLINE_NONE,
                                    Bold.CHAR_BOLD_OFF,
                                    Reverse.CHAR_REVERSE_OFF,
                                    Rotate.ROTATE_NONE);

                            // To print the date and time.
                            mPrinterManager.PrintText(receiptTime);
                            break;
                        default:
                            break;
                    }


                    //===== Content =====
                    switch (printMode)
                    {
                        case STANDARD_MODE:
                            // To specify the absolute position.
                            mPrinterManager.SetHorizontalPosition(HORIZONTAL_POS);

                            // Printing the contents of the time and date and the receipt, and then two lines feed.
                            mPrinterManager.PrintText(receiptTime + receiptContent);
                            mPrinterManager.FeedLine(2);
                            break;
                        case PAGE_MODE:
                            // Select a page mode.
                            startX = (receiptWidth - ((WIDTH_FONT_A + RIGHT_SPACE) * 32)) / 2;
                            startY += height + 40;
                            width = receiptWidth - startX;
                            height = (HEIGHT_FONT_A + (LINE_SPACE - HEIGHT_FONT_A)) * 21;

                            mPrinterManager.SelectPageMode(startX,
                                    startY,
                                    width,
                                    height,
                                    Direction.DIRECTION_LEFT_TO_RIGHT);

                            // To specifies the vertical direction of the absolute position of the page mode.
                            mPrinterManager.SetPageModeVerticalPosition(HEIGHT_FONT_A);

                            // To print the contents of the receipt.
                            mPrinterManager.PrintText(receiptContent);
                            break;
                        default:
                            break;
                    }

                    //===== Barcode =====
                    switch (printMode)
                    {
                        case STANDARD_MODE:
                            // Select the print direction of the bar code, specify the absolute position.
                            mPrinterManager.SetStandardModeBarcodeDirection(Rotate.ROTATE_CURRENT);
                            mPrinterManager.SetHorizontalPosition(HORIZONTAL_POS);
                            break;
                        case PAGE_MODE:
                            // Select a page mode.
                            startX = 100;
                            startY += height + 40;
                            width = receiptWidth - startX;
                            height = 200;

                            mPrinterManager.SelectPageMode(startX,
                                    startY,
                                    width,
                                    height,
                                    Direction.DIRECTION_LEFT_TO_RIGHT);

                            // To specifies the vertical direction of the absolute position of the page mode.
                            mPrinterManager.SetPageModeVerticalPosition(162);
                            break;
                        default:
                            break;
                    }

                    // To print the bar code.
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_UPC_A,
                            receiptBarcode,
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_3,
                            HEIGHT_BARCODE,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);

                    //===== 2Dcode =====
                    switch (printMode)
                    {
                        case STANDARD_MODE:
                            // To specifies the absolute position.
                            mPrinterManager.SetHorizontalPosition(HORIZONTAL_POS);
                            break;
                        case PAGE_MODE:
                            // Select a page mode.
                            startX = 150;
                            startY += height + 40;
                            width = receiptWidth - startX;
                            height = 100;

                            mPrinterManager.SelectPageMode(startX,
                                    startY,
                                    width,
                                    height,
                                    Direction.DIRECTION_LEFT_TO_RIGHT);

                            // To specifies the vertical direction of the absolute position of the page mode.
                            mPrinterManager.SetPageModeVerticalPosition(90);
                            break;
                        default:
                            break;
                    }

                    // To print a two-dimensional bar code.
                    mPrinterManager.Print2Dcode(Type2Dcode.TYPE_2DCODE_PDF417,
                            receipt2Dcode,
                            Mode2Dcode.MODE_2DCODE_PDF417_STANDARD,
                            ModuleSize2Dcode.MODULE_SIZE_2DCODE_3,
                            HEIGHT_2DCODE,
                            COLUM_2DCODE,
                            ROW_2DCODE,
                            ErrorCorrect2Dcode.ERR_CORRECTION_2DCODE_PDF417_0);

                    if (printMode == PAGE_MODE)
                    {
                        // In the case of the page mode, perform the printing of the page mode, select a standard mode.
                        mPrinterManager.PrintPageModeData();
                        mPrinterManager.SelectStandardMode();
                    }


                    //===== cut receipt =====
                    // To feed the paper cut position.
                    mPrinterManager.FeedCutPosition();

                    //===== Print transaction
                    // To start the printing data batch transmission (exit printing).
                    mPrinterManager.ControlTransaction(TransactionFunction.TRANSACTION_PRINT);

                }

            }

            catch (PrinterException err)
            {
                // If the printer exception occurs, To display the error code.
                MessageBox.Show("Error Code = " + err.GetErrorCode().ToString());
            }
            finally
            {
                // Be sure to call the close.
                Close();
            }

        }

        /// <summary>
        /// Processing in the case of "SendFile" button has been pressed
        /// </summary>
        private void SendDataFileSample()
        {
            try
            {
                // Open the PrinterManager.
                Open();

                if (mPrinterManager.IsOpened)
                {
                    // To print a variety of files. (In the folder of the following you need to copy a file that was distributed.)
                    // PC\USER\\\Program Files\siimpprintersample\testfiles
                    mPrinterManager.SetStandardModeAlignment(Alignment.ALIGN_LEFT);
                    mPrinterManager.PrintText("SendDataFile\n");

                    mPrinterManager.PrintText("----------- bmp file -----------\n");
                    mPrinterManager.SendDataFile(m_CurrentPath + "bitmapfile.bmp");

                    mPrinterManager.PrintText("\n----------- txt file -----------\n");
                    mPrinterManager.SendDataFile(m_CurrentPath + "textfile.txt");

                    mPrinterManager.PrintText("\n----------- bin file -----------\n");
                    mPrinterManager.SendDataFile(m_CurrentPath + "binfile.bin");

                    mPrinterManager.PrintText("\n----------- dat file -----------\n");
                    mPrinterManager.SendDataFile(m_CurrentPath + "datfile.dat");

                    if (m_PrinterModel == PrinterModel.PRN_MODEL_MP_A40)
                    {
                        mPrinterManager.PrintText("\n----------- html file ----------\n");
                        mPrinterManager.SendDataFile(m_CurrentPath + "htmlfile.html");

                        mPrinterManager.PrintText("\n----------- htm file -----------\n");
                        mPrinterManager.SendDataFile(m_CurrentPath + "htmfile.htm");
                    }

                }

            }

            catch (PrinterException err)
            {
                // If the printer exception occurs, To display the error code.
                MessageBox.Show("Error Code = " + err.GetErrorCode().ToString());
            }
            finally
            {
                // Be sure to call the close.
                Close();
            }
        }

        /// <summary>
        /// Processing when the "Barcode" button has been pressed
        /// </summary>
        private void BarcodeSample()
        {
            try
            {
                // Open the PrinterManager.
                Open();

                if (mPrinterManager.IsOpened)
                {
                    // We will continue to print to continue a variety of bar code.
                    mPrinterManager.PrintText("printBarcode\n\n");

                    mPrinterManager.PrintText("UPC-A\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_UPC_A,
                            "012345678905",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);

                    mPrinterManager.PrintText("\nUPC-E\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_UPC_E,
                            "01200000123",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2_5);
                    mPrinterManager.PrintText("\nJAN13\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_JAN13,
                            "012345678912",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);
                    mPrinterManager.PrintText("\nJAN8\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_JAN8,
                            "0123456",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);
                    mPrinterManager.PrintText("\nCODE39\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_CODE39,
                            "A",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);

                    mPrinterManager.PrintText("\nITF\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_ITF,
                            "01",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);

                    mPrinterManager.PrintText("\nCODABAR\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_CODABAR,
                            "B+C",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);
                    mPrinterManager.PrintText("\nCODE128\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_CODE128,
                            "{A0123456789",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);
                    mPrinterManager.PrintText("\nCODE93\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_CODE93,
                            "0123456789",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);
                    mPrinterManager.PrintText("\nJAN13-ADDON2\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_JAN13_ADDON2,
                            "49012345678940",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);
                    mPrinterManager.PrintText("\nJAN13-ADDON5\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_JAN13_ADDON5,
                            "49012345678940123",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);
                    mPrinterManager.PrintText("\nGS1-OMNI-DIRECTIONAL\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_GS1_OMNI_DIRECTIONAL,
                            "4901234567894",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);
                    mPrinterManager.PrintText("\nGS1-TRUNCATED\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_GS1_TRUNCATED,
                            "4901234567894",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);
                    mPrinterManager.PrintText("\nGS1-LIMITED\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_GS1_LIMITED,
                            "0123456789012",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);
                    mPrinterManager.PrintText("\nGS1-EXPANDED\n");
                    mPrinterManager.PrintBarcode(TypeBarcode.TYPE_BARCODE_GS1_EXPANDED,
                            "490{123456789",
                            ModuleWidthBarcode.MODULE_WIDTH_BARCODE_2,
                            100,
                            HriPositionBarcode.HRI_BARCODE_BOTTOM_FONT_A,
                            NwRatioBarcode.NWRATIO_BARCODE_1TO2);

                }

            }

            catch (PrinterException err)
            {
                // If the printer exception occurs, To display the error code.
                MessageBox.Show("Error Code = " + err.GetErrorCode().ToString());
            }
            finally
            {
                // Be sure to call the close.
                Close();
            }
        }

        /// <summary>
        /// Processing in the case of "2Dcode" button has been pressed
        /// </summary>
        private void TwoDCodeSample()
        {
            try
            {
                // Open the PrinterManager.
                Open();

                if (mPrinterManager.IsOpened)
                {
                    // We will continue to print to continue a variety of 2D code.
                    mPrinterManager.PrintText("print2Dcode\n");

                    mPrinterManager.PrintText("\nQR Code\n");
                    mPrinterManager.Print2Dcode(Type2Dcode.TYPE_2DCODE_QR_CODE,
                            "ABC0123456789",
                            Mode2Dcode.MODE_2DCODE_QR_CODE_MODEL2,
                            ModuleSize2Dcode.MODULE_SIZE_2DCODE_DEFAULT,
                            0,
                            0,
                            0,
                            ErrorCorrect2Dcode.ERR_CORRECTION_2DCODE_QR_CODE_L);
                    mPrinterManager.PrintText("\nPDF417\n");
                    mPrinterManager.Print2Dcode(Type2Dcode.TYPE_2DCODE_PDF417,
                             "ABC0123456789",
                             Mode2Dcode.MODE_2DCODE_PDF417_STANDARD,
                             ModuleSize2Dcode.MODULE_SIZE_2DCODE_DEFAULT,
                             10,
                             0,
                             0,
                             ErrorCorrect2Dcode.ERR_CORRECTION_2DCODE_PDF417_0);
                    mPrinterManager.PrintText("\nDATA MATRIX\n");
                    mPrinterManager.Print2Dcode(Type2Dcode.TYPE_2DCODE_DATA_MATRIX,
                             "ABC0123456789",
                             Mode2Dcode.MODE_2DCODE_DATA_MATRIX_AUTO,
                             ModuleSize2Dcode.MODULE_SIZE_2DCODE_DEFAULT,
                             0,
                             0,
                             0,
                             ErrorCorrect2Dcode.ERR_CORRECTION_2DCODE_NONE);

                    mPrinterManager.PrintText("\nMAXI CODE\n");
                    mPrinterManager.Print2Dcode(Type2Dcode.TYPE_2DCODE_MAXI_CODE,
                             "111222333333333ABC0123456789DEF",
                             Mode2Dcode.MODE_2DCODE_MAXI_CODE_2,
                             ModuleSize2Dcode.MODULE_SIZE_2DCODE_DEFAULT,
                             0,
                             0,
                             0,
                             ErrorCorrect2Dcode.ERR_CORRECTION_2DCODE_NONE);
                    mPrinterManager.PrintText("\nGS1 STACKED\n");
                    mPrinterManager.Print2Dcode(Type2Dcode.TYPE_2DCODE_GS1_STACKED,
                             "1230123456789",
                             Mode2Dcode.MODE_2DCODE_NONE,
                             ModuleSize2Dcode.MODULE_SIZE_2DCODE_DEFAULT,
                             0,
                             0,
                             0,
                             ErrorCorrect2Dcode.ERR_CORRECTION_2DCODE_NONE);

                    //GS1_STACKED_OMNI_DIRECTIONAL
                    mPrinterManager.PrintText("\nGS1 STACKED OMNI DIRECTIONAL\n");
                    mPrinterManager.Print2Dcode(Type2Dcode.TYPE_2DCODE_GS1_OMNI_DIRECTIONAL,
                             "1230123456789",
                             Mode2Dcode.MODE_2DCODE_NONE,
                             ModuleSize2Dcode.MODULE_SIZE_2DCODE_DEFAULT,
                             33,
                             0,
                             0,
                             ErrorCorrect2Dcode.ERR_CORRECTION_2DCODE_NONE);

                    //GS1_EXPANDED_STACKED
                    mPrinterManager.PrintText("\nGS1 EXPANDED STACKED\n");
                    mPrinterManager.Print2Dcode(Type2Dcode.TYPE_2DCODE_GS1_EXPANDED_STACKED,
                             "1",
                             Mode2Dcode.MODE_2DCODE_NONE,
                             ModuleSize2Dcode.MODULE_SIZE_2DCODE_DEFAULT,
                             0,
                             2,
                             0,
                             ErrorCorrect2Dcode.ERR_CORRECTION_2DCODE_NONE);
                }

            }

            catch (PrinterException err)
            {
                // If the printer exception occurs, To display the error code.
                MessageBox.Show("Error Code = " + err.GetErrorCode().ToString());
            }
            finally
            {
                // Be sure to call the close.
                Close();
            }
        }
        #endregion

        /// <summary>
        /// Open the PrinterManager.
        /// </summary>
        public void Open()
        {
            try
            {
                // To create a log file.
                mPrinterManager.SetLog(0, LogFileSize.LOG_FILE_SIZE_5MB);

                // Set the string of address input for the text box to the address for the member variable.
                m_Address = textBox_Address.Text;

                // Call the Open method of PrintManager.
                mPrinterManager.Open(GetCurrentInterface(),
                                    m_PrinterModel,
                                    GetCurrentAddress(),
                                    60);
            }
            // If the printer exception occurs, To display the error code.
            catch (PrinterException ex) { MessageBox.Show("ErrorCode = " + ex.GetErrorCode().ToString()); }
            catch (Exception ex) { MessageBox.Show(ex.Message); }

        }

        /// <summary>
        /// Close the PrinterManager.
        /// </summary>
        public new void Close()
        {
            if (mPrinterManager != null && mPrinterManager.IsOpened)
            {
                // If mPrinterManager has been set, and the case of mPrinterManager.IsOpened
                try
                {
                    // Close the PrinterManager.
                    Thread.Sleep(100);      // 100ms of Sleep is does not make sense in particular.
                    mPrinterManager.Close();
                }
                // If the printer exception occurs, To display the error code.
                catch (PrinterException ex) { MessageBox.Show("ErrorCode = " + ex.GetErrorCode().ToString()); }
                catch (Exception ex) { MessageBox.Show(ex.Message); }
            }
        }

        /// <summary>
        /// Event when a printer model is selected.
        /// </summary>
        private void listBox_PrinterModel_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (listBox_PrinterModel.SelectedItem.ToString() == PRINTER_MODEL_MP_A40)
            {
                button_PageMode.Enabled = true;
                radioButton3.Enabled = true;
                m_PrinterModel = PrinterModel.PRN_MODEL_MP_A40;
            }
            else if (listBox_PrinterModel.SelectedItem.ToString() == PRINTER_MODEL_MP_B30)
            {
                button_PageMode.Enabled = true;
                radioButton3.Enabled = true;
                m_PrinterModel = PrinterModel.PRN_MODEL_MP_B30;
            }
            else if (listBox_PrinterModel.SelectedItem.ToString() == PRINTER_MODEL_MP_B20)
            {
                button_PageMode.Enabled = false;
                radioButton3.Enabled = false;
                m_PrinterModel = PrinterModel.PRN_MODEL_MP_B20;
            }
            else
            {
                button_PageMode.Enabled = true;
                radioButton3.Enabled = true;
                m_PrinterModel = PrinterModel.PRN_MODEL_MP_B30;
            }

            if (GetCurrentInterface() == PrinterInterface.PRN_IF_USB)
            {
                textBox_Address.Enabled = false;
                button_DiscoveryList.Enabled = false;
            }
            else
            {
                textBox_Address.Enabled = true;
                button_DiscoveryList.Enabled = true;
            }
        }

    }
}